@@ -7,9 +7,14 @@ import pandas as pd
 
 dates = pd.date_range('01:00', '01:00:01.200', freq='1ms')
 prices = pd.Series(np.random.random(len(dates))).rolling(30).mean() + 4
-fplt.plot(dates, prices)
+fplt.plot(dates, prices, width=3)
 line = fplt.add_line((dates[100], 4.4), (dates[1100], 4.6), color='#9900ff', interactive=True)
 ## fplt.remove_line(line)
 text = fplt.add_text((dates[500], 4.6), "I'm here alright!", color='#bb7700')
 ## fplt.remove_text(text)
+
+def save():
+    fplt.screenshot(open('screenshot.png', 'wb'))
+fplt.timer_callback(save, 0.5, single_shot=True) # wait some until we're rendered
+
 fplt.show()
